@@ -1,6 +1,5 @@
 import os
 import subprocess
-import sys
 from glob import glob
 from pathlib import Path
 from typing import Any, Optional
@@ -11,6 +10,7 @@ from docker.errors import ImageNotFound  # type: ignore
 
 from treebeard.buildtime.helper import run_image
 from treebeard.conf import treebeard_env
+from treebeard.util import fatal_exit
 
 
 def download_archive(unzip_location: str, download_location: str, url: str):
@@ -31,6 +31,7 @@ def run_repo(
     build_tag: str,
     repo_url: str,
     secrets_url: Optional[str],
+    local: bool = False,
 ):
     client: Any = docker.from_env()  # type: ignore
 
@@ -57,7 +58,7 @@ def run_repo(
     # Pull down images to use in cache
     image_name = f"gcr.io/treebeard-259315/projects/{project_id}/{notebook_id}"
     # our "base" image is just a routine repo2docker build which can be used for caching
-    project_base_image = "gcr.io/treebeard-259315/project-base-image"
+    project_base_image = "docker.io/treebeardtech/project-base-image"
 
     try:
         client.images.pull(image_name)
@@ -86,7 +87,14 @@ def run_repo(
     """
     subprocess.check_output(["bash", "-c", r2d])
     subprocess.check_output(["docker", "tag", versioned_image_name, latest_image_name])
-    run_image(project_id, notebook_id, run_id, image_name)
+
+    try:
+        run_image(project_id, notebook_id, run_id, image_name)
+    except Exception as ex:
+        if not local:
+            click.echo("Image run failed, pushing failed image...")
+            client.images.push(latest_image_name)
+        raise ex
 
 
 if __name__ == "__main__":
@@ -98,13 +106,11 @@ if __name__ == "__main__":
 
     build_tag = os.getenv(build_tag_key)
     if not build_tag:
-        click.echo(f"Fatal: No build_tag provided inside {build_tag_key}")
-        sys.exit(1)
+        fatal_exit(f"No build_tag provided inside {build_tag_key}")
 
     repo_url = os.getenv(repo_url_key)
     if not repo_url:
-        click.echo(f"Fatal: No repo_url provided inside {repo_url_key}")
-        sys.exit(1)
+        fatal_exit(f"No repo_url provided inside {repo_url_key}")
 
     secrets_url = os.getenv(secrets_url_key)
     if not treebeard_env.notebook_id:
